Numina Documentation — Numina 0.20.dev0 documentation

# Numina Documentation

Welcome. This is the Documentation for Numina (version 0.20, date Mar 01, 2019),

Numina user guide: Numina User Guide

Numina pipeline creation guide: Numina Pipeline Creation Guide

Numina reference guide: Numina Reference.

- Numina User Guide
- Numina Pipeline Creation Guide
- Numina Reference
- Glossary

Maintainers: Sergio Pascual sergiopr@fis.ucm.es, Nicolás Cardiel cardiel@ucm.es